#
# spec file for package libpng15
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#
%define major   1
%define minor   5
%define micro   22
%define branch  %{major}%{minor}
%define libname libpng%{branch}-%{branch}

Name:           libpng15
Url:            http://www.libpng.org/pub/png/libpng.html
Version:        %{major}.%{minor}.%{micro}
Release:        5.5
Summary:        Library for the Portable Network Graphics Format (PNG)
License:        Libpng
Group:          System/Libraries
Source:         http://downloads.sourceforge.net/project/libpng/%{name}/%{version}/libpng-%{version}.tar.xz
Source2:        baselibs.conf
Patch0:         libpng15-CVE-2015-8126.patch
Patch1:         libpng15-CVE-2015-8126-complete.patch
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  zlib-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%define debug_package_requires %{libname} = %{version}-%{release}

%package -n %{libname}

Summary:        Library for the Portable Network Graphics Format (PNG)
Group:          System/Libraries
# bug437293
%ifarch ppc64
Obsoletes:      libpng-64bit
%endif
#

%description
libpng is the official reference library for the Portable Network
Graphics format (PNG).

%description -n %{libname}
libpng is the official reference library for the Portable Network
Graphics format (PNG).

%prep
%setup -n libpng-%{version}
%patch0
%patch1

%build
# PNG_SAFE_LIMITS_SUPPORTED: http://www.openwall.com/lists/oss-security/2015/01/10/1
export CFLAGS="%optflags -O3 -DPNG_SAFE_LIMITS_SUPPORTED -DPNG_SKIP_SETJMP_CHECK $(getconf LFS_CFLAGS)"
export LDFLAGS="-Wl,-z,relro,-z,now"

%configure \
              --disable-static
make %{?_smp_mflags}

%check
make check

%install
mkdir -p %{buildroot}/%{_libdir}
install .libs/libpng%{branch}.so.%{branch}.%{micro}.0 %{buildroot}/%{_libdir}
ln -s %{branch}.so.%{branch}.%{micro}.0 %{buildroot}/%{_libdir}/libpng%{branch}.so.%{branch} 

%post -n %{libname} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%defattr(-,root,root)
%{_libdir}/libpng%{branch}.so.*

%changelog
* Thu Dec  3 2015 pgajdos@suse.com
- security update:
  * CVE-2015-8126 fixed incompletely [bsc#954980]
  + libpng15-CVE-2015-8126-complete.patch
* Mon Nov 16 2015 pgajdos@suse.com
- security update:
  * CVE-2015-8126 [bsc#954980]
  + libpng15-CVE-2015-8126.patch
* Thu Sep 24 2015 pgajdos@suse.com
- correctly install library link [bnc#947278]
* Mon Aug 10 2015 cdenicolo@suse.com
- license update: Libpng
  see LICENSE file
* Mon Mar 30 2015 pgajdos@suse.com
- updated to 1.5.22 [fate#319047]
* Mon Dec 29 2014 pgajdos@suse.com
- updated to 1.5.21
* Thu Nov 20 2014 pgajdos@suse.com
- updated to 1.5.20
* Fri Aug 22 2014 pgajdos@suse.com
- updated to 1.5.19
* Fri Feb  7 2014 pgajdos@suse.com
- updated to 1.5.18
* Mon Jul  1 2013 pgajdos@suse.com
- updated to 1.5.17:
  Removed a redundant test from png_set_IHDR().
  Added set(CMAKE_CONFIGURATION_TYPES ...) to CMakeLists.txt (Andrew Hundt)
  Deleted set(CMAKE_BUILD_TYPE) block from CMakeLists.txt
  Make ARM NEON support work at compile time (not just configure time).
    This moves the test on __ARM_NEON__ into pngconf.h to avoid issues when
    using a compiler that compiles for multiple architectures at one time.
  Removed PNG_FILTER_OPTIMIZATIONS and PNG_ARM_NEON_SUPPORTED from
    pnglibconf.h, allowing more of the decisions to be made internally
    (pngpriv.h) during the compile.  Without this, symbol prefixing is broken
    under certain circumstances on ARM platforms.  Now only the API parts of
    the optimizations ('check' vs 'api') are exposed in the public header files
    except that the new setting PNG_ARM_NEON_OPT documents how libpng makes the
    decision about whether or not to use the optimizations.
  Protect symbol prefixing against CC/CPPFLAGS/CFLAGS useage.
    Previous iOS/Xcode fixes for the ARM NEON optimizations moved the test
    on __ARM_NEON__ from configure time to compile time.  This breaks symbol
    prefixing because the definition of the special png_init_filter_functions
    call was hidden at configure time if the relevant compiler arguments are
    passed in CFLAGS as opposed to CC.  This change attempts to avoid all
    the confusion that would result by declaring the init function even when
    it is not used, so that it will always get prefixed.
  Revised libpng.3 so that "doclifter" can process it.
  Revised example.c to illustrate use of PNG_DEFAULT_sRGB and PNG_GAMMA_MAC_18
    as parameters for png_set_gamma().  These have been available since
    libpng-1.5.4.
* Thu May 23 2013 pgajdos@suse.com
- updated to 1.5.16:
  Corrected a misplaced closing bracket in contrib/libtests/pngvalid.c
    (Flavio Medeiros).
  Revised stack marking in arm/filter_neon.S and configure.ac
  Ensure that NEON filter stuff is completely disabled when switched 'off'.
    Previously the ARM NEON specific files were still built if the option
    was switched 'off' as opposed to being explicitly disabled.
  Avoid a compiler warning about unused png_ptr in translate_gamma_flags()
  Revise pngtest.c to skip tests of unsupported features.
  Test for 'arm*' not just 'arm' in the host_cpu configure variable.
  Rebuilt the configure scripts.
  Expanded manual paragraph about writing private chunks, particularly
    the need to call png_set_keep_unknown_chunks() when writing them.
  Updated contrib/pngminus/pnm2png.c (Paul Stewart):
    Check for EOF
    Ignore "#" delimited comments in input file to pnm2png.c.
    Fixed whitespace handling
    Added a call to png_set_packing()
    Initialize dimension values so if sscanf fails at least we have known
    invalid values.
  Allow contrib/pnminus/pnm2png.c to compile without WRITE_INVERT and
    WRITE_PACK supported (writes error message that it can't read P1 or P4
    PBM files).
  Revised contrib/pngminim/*/makefile to separate CPPFLAGS and CFLAGS, and
    to generate pnglibconf.h with the right zlib header files.
  Ported contrib/pngminus/pnm2png.c changes back from libpng-1.6.3beta06,
    to use unsigned long, not png_uint_32 arguments to sscanf().
* Mon Apr 15 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Thu Mar 28 2013 pgajdos@suse.com
- updated to 1.5.15:
  Enabled renaming of the extern (but not DLL exported) ARM filter functions.
    Also enabled inclusion of pngpriv.h in non-C files by preventing C/C++
    specific definitions if PNG_VERSION_INFO_ONLY is defined.
  Added png_get_palette_max() function.
  Made a probably general fix for the preprocessing used to generate source
    files. This change might make the check for a special C preprocessor
    unnecessary, and it also eliminates the requirement for sed in the
    configure build process.
  Turn serial tests back on (recently turned off by autotools upgrade).
  Enclosed the new png_get_palette_max in #ifdef PNG_GET_PALETTE_MAX_SUPPORTED
    block, and revised pnglibconf.h and pnglibconf.h.prebuilt accordingly.
  Fixed a race condition in the creation of the build 'scripts' directory
    while building with a parallel make.
  Use parentheses more consistently in "#if defined(MACRO)" tests.
  Fixed PNG_ALIGN(ED)_MEMORY and add ability to turn off ARM_NEON
    runtime checks
  Updated the INSTALL document.
  Revised INSTALL to recommend using CPPFLAGS instead of INCLUDES.
  Avoid a possible memory leak in contrib/gregbook/readpng.c
  etc. see ANNOUNCE or CHANGES
* Tue Jan 29 2013 pgajdos@suse.com
- updated to 1.5.14:
  Ignore, with a warning, out-of-range value of num_trans in png_set_tRNS().
  Fixed a minor bug in types to malloc and major bug in handling compressed
    iTXt. Compressed iTXt could not be handled.
  Check validity of "num_unknowns" parameter of png_set_unknown_chunks()
    (Bug report from yuris).
  Check the validity of the "nentries" parameter of png_set_sPLT() and the
  "num_text" parameter of png_set_text_2().
* Wed Oct 24 2012 jengelh@inai.de
- Add missing baselib requires for compat-devel-32bit
* Thu Sep 27 2012 pgajdos@suse.com
- updated to 1.5.13:
  Do not compile PNG_DEPRECATED, PNG_ALLOC and PNG_PRIVATE when __GNUC__ < 3.
  Removed references to png_zalloc() and png_zfree() from the manual.
  Revised PNG_FP_EXPORT and PNG_FIXED_EXPORT macros to avoid generating
    lone semicolons (patch ported from libpng-1.6.0beta11).
  Corrected handling of the image array and the row_pointers array in example.
  When png_set_filler is used to strip a filler channel during write, the
    code prior to 1.5 would ignore the case where the output required an
    alpha channel or when the output was a palettized PNG.  In libpng-1.5 the
    ignorance was lost and libpng proceeded to strip the channel resulting
    in a bad (potential memory overwrite) failure later.  This reverts
    the behavior to the pre-1.5 state but issues a warning. libpng-1.6 is
    expected to issue an error on the erroneous png_set_filler call.
  Use png_memset() consistently (pngmem.c contained some bare "memset" calls).
* Wed Jul 11 2012 pgajdos@suse.com
- updated to 1.5.12:
  Changed "a+w" to "u+w" in Makefile.in to fix CVE-2012-3386.
* Fri Jun 15 2012 pgajdos@suse.com
- updated to 1.5.11:
  Enable png_set_check_for_invalid_index() for both read and write.
  Made fixes for new optimization warnings from gcc 4.7.0. The compiler
    performed an optimization which is safe but then warned about it.
    Changing the type of 'palette_number' in pngvalid.c removes the warning.
  Improved efficiency of new do_check_palette_indexes() function.
  Don't check palette indexes if num_palette is 0 (as it can be in MNG files).
  Added two images to contrib/pngsuite (1-bit and 2-bit transparent grayscale),
    and renamed three whose names were inconsistent with those in
    pngsuite/README.txt.
* Thu Mar 29 2012 pgajdos@suse.com
- updated to 1.5.10:
  Removed two useless #ifdef directives from pngread.c and one from pngrutil.c
  Always put the CMAKE_LIBRARY in "lib" (removed special WIN32 case).
  Removed empty vstudio/pngstest directory (Clifford Yapp).
  Eliminated redundant png_push_read_tEXt|zTXt|iTXt|unknown code from
    pngpread.c and use the sequential png_handle_tEXt, etc., in pngrutil.c;
    now that png_ptr->buffer is inaccessible to applications, the special
    handling is no longer useful.
  Fixed bug with png_handle_hIST with odd chunk length (Frank Busse).
  Added PNG_SAFE_LIMITS feature to pnglibconf.dfa and code in pngconf.h
    to reset the user limits to safe ones if PNG_SAFE_LIMITS is defined.
    To enable, use "CPPFLAGS=-DPNG_SAFE_LIMITS_SUPPORTED" on the configure
    command or put "#define PNG_SAFE_LIMITS_SUPPORTED" in pnglibconf.h.
  Revised the SAFE_LIMITS feature to be the same as the feature in libpng16.
  Added information about the new limits in the manual.
  Updated Makefile.in
  Removed unused "current_text" members of png_struct and the png_free()
    of png_ptr->current_text from pngread.c
  Fixed PNG_LIBPNG_BUILD_BASE_TYPE definition.
  Fixed CMF optimization of non-IDAT compressed chunks, which was added at
    libpng-1.5.4.  It sometimes produced too small of a window.
  Reject all iCCP chunks after the first, even if the first one is invalid.
  Added palette-index checking. Issue a png_benign_error() if an invalid
    index is found.
  Revised example.c to put text strings in a temporary character array
    instead of directly assigning string constants to png_textp members.
    This avoids compiler warnings when -Wwrite-strings is enabled.
  Prevent PNG_EXPAND+PNG_SHIFT doing the shift twice.
  Revised png_set_text_2() to avoid potential memory corruption (fixes
    CVE-2011-3048).
* Mon Feb 20 2012 pgajdos@suse.com
- updated to 1.5.9:
  * fixed CVE-2011-3026 [bnc#747311]
* Thu Feb  2 2012 pgajdos@suse.com
- updated to 1.5.8:
  Fixed one-byte (stack) buffer-overrun bug in png_formatted_warning()
  (CVE-2011-3464)
* Mon Dec 19 2011 pgajdos@suse.com
- updated to 1.5.7:
  Added support for ARM processor (Mans Rullgard)
  Fixed bug in pngvalid on early allocation failure; fixed type cast in
    pngmem.c; pngvalid would attempt to call png_error() if the allocation
    of a png_struct or png_info failed. This would probably have led to a
    crash.  The pngmem.c implementation of png_malloc() included a cast
    to png_size_t which would fail on large allocations on 16-bit systems.
  Fix for the preprocessor of the Intel C compiler. The preprocessor
    splits adjacent @ signs with a space; this changes the concatentation
    token from @-@-@ to PNG_JOIN; that should work with all compiler
    preprocessors.
  Paeth filter speed improvements from work by Siarhei Siamashka. This
    changes the 'Paeth' reconstruction function to improve the GCC code
    generation on x86. The changes are only part of the suggested ones;
    just the changes that definitely improve speed and remain simple.
    The changes also slightly increase the clarity of the code.
  Check compression_type parameter in png_get_iCCP and remove spurious
    casts. The compression_type parameter is always assigned to, so must
    be non-NULL. The cast of the profile length potentially truncated the
    value unnecessarily on a 16-bit int system, so the cast of the (byte)
    compression type to (int) is specified by ANSI-C anyway.
  Fixed FP division by zero in pngvalid.c; the 'test_pixel' code left
    the sBIT fields in the test pixel as 0, which resulted in a floating
    point division by zero which was irrelevant but causes systems where
    FP exceptions cause a crash. Added code to pngvalid to turn on FP
    exceptions if the appropriate glibc support is there to ensure this is
    tested in the future.
  Updated scripts/pnglibconf.mak and scripts/makefile.std to handle the
    new PNG_JOIN macro.
  Added versioning to pnglibconf.h comments.
  Simplified read/write API initial version; basic read/write tested on
    a variety of images, limited documentation (in the header file.)
  Installed more accurate linear to sRGB conversion tables. The slightly
    modified tables reduce the number of 16-bit values that
    convert to an off-by-one 8-bit value.  The "makesRGB.c" code that was used
    to generate the tables is now in a contrib/sRGBtables sub-directory.
  etc. see CHANGES
* Thu Dec  1 2011 idoenmez@suse.de
- Name field shouldn't contain a macro
* Thu Dec  1 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Thu Nov  3 2011 pgajdos@suse.com
- updated to 1.5.6:
  Fixed some 64-bit type conversion warnings in pngrtran.c
  Moved row_info from png_struct to a local variable.
  The various interlace mask arrays have been made into arrays of
    bytes and made PNG_CONST and static (previously some arrays were
    marked PNG_CONST and some weren't).
  Additional checks have been added to the transform code to validate the
    pixel depths after the transforms on both read and write.
  Removed some redundant code from pngwrite.c, in png_desgtroy_write_struct().
  Changed chunk reading/writing code to use png_uint_32 instead of png_byte[4].
    This removes the need to allocate temporary strings for chunk names on
    the stack in the read/write code.  Unknown chunk handling still uses the
    string form because this is exposed in the API.
  Added a note in the manual the png_read_update_info() must be called only
    once with a particular info_ptr.
  Revised test-pngtest.sh to report FAIL when pngtest fails.
  Added "--strict" option to pngtest, to report FAIL when the failure is
    only because the resulting valid files are different.
  Revised CMakeLists.txt to work with mingw and removed some material from
    CMakeLists.txt that is no longer useful in libpng-1.5.
  Fixed typo in Makefile.in and Makefile.am ("-M Wl" should be "-M -Wl")."
  Speed up png_combine_row() for interlaced images. This reduces the generality
    of the code, allowing it to be optimized for Adam7 interlace.  The masks
    passed to png_combine_row() are now generated internally, avoiding
    some code duplication and localizing the interlace handling somewhat.
  Align png_struct::row_buf - previously it was always unaligned, caused by
    a bug in the code that attempted to align it; the code needs to subtract
    one from the pointer to take account of the filter byte prepended to
    each row.
  Optimized png_combine_row() when rows are aligned. This gains a small
    percentage for 16-bit and 32-bit pixels in the typical case where the
    output row buffers are appropriately aligned. The optimization was not
    previously possible because the png_struct buffer was always misaligned.
  Removed two redundant tests for unitialized row.
  Fixed a relatively harmless memory overwrite in compressed text writing
    with a 1 byte zlib buffer.
  Add ability to call png_read_update_info multiple times to pngvalid.c
  Fixes for multiple calls to png_read_update_info. These fixes attend to
    most of the errors revealed in pngvalid, however doing the gamma work
    twice results in inaccuracies that can't be easily fixed.  There is now
    a warning in the code if this is going to happen.
  Turned on multiple png_read_update_info in pngvalid transform tests.
  Prevent libpng from overwriting unused bits at the end of the image when
    it is not byte aligned, while reading. Prior to libpng-1.5.6 libpng would
    overwrite the partial byte at the end of each row if the row width was not
    an exact multiple of 8 bits and the image is not interlaced.
  Made png_ptr->prev_row an aligned pointer into png_ptr->big_prev_row
    (Mans Rullgard).
  Changed misleading "Missing PLTE before cHRM" warning to "Out of place cHRM"
  Added PNG_LSR() and PNG_LSL() macros to defend against buggy compilers that
    evaluate non-taken code branches and complain about out-of-range shifts.
  Renamed the local variable 'byte' because it appears in a MSYS header
    file.
  Added #define PNG_ALIGN_TYPE PNG_ALIGN_NONE to contrib/pngminim/*/pngusr.h
* Mon Sep 26 2011 pgajdos@suse.com
- updated to 1.5.5, fixes:
  * CVE-2011-3328 [bnc#720017]
* Tue Jul 26 2011 pgajdos@novell.com
- updated to 1.5.4, fixes:
  * CVE-2011-2501 [bnc#702578]
  * CVE-2011-2690 [bnc#706387]
  * CVE-2011-2691 [bnc#706388]
  * CVE-2011-2692 [bnc#706389]
* Thu Mar 31 2011 pgajdos@suse.cz
- updated to 1.5.2:
  * Turned on interlace handling in png_read_png().
  * Fixed gcc pendantic warnings.
  * Fixed png_get_current_row_number() in the interlaced case.
  * Cleaned up ALPHA flags and transformations.
  * Implemented expansion to 16 bits.
  * etc, see
    http://sourceforge.net/projects/libpng/files/libpng15/1.5.2/
* Thu Feb  3 2011 pgajdos@suse.cz
- updated to 1.5.1: new branch shortly after 1.4, many structural
  changes, see CHANGELOG or
  http://sourceforge.net/projects/libpng/files/libpng15/1.5.0/
  and
  http://sourceforge.net/projects/libpng/files/libpng15/1.5.1/
* Thu Sep 30 2010 pgajdos@novell.com
- updated to 1.4.4:
  * Eliminated another deprecated reference to png_ptr->io_ptr in pngtest.c
  * Updated the xcode project to work with libpng-1.4.x and added iOS targets
    for simulator and device (Philippe Hausler).
  * Eliminated a deprecated reference to png_ptr->io_ptr in pngtest.c
  * Removed unused png_mem_* defines from pngconf.h.
  * Updated the read macros and functions from 1.5.0beta38.
* Mon Aug 30 2010 coolo@novell.com
- fix baselibs.conf after previous change
* Thu Jul 29 2010 pgajdos@suse.cz
- add devel packages to baselbis.conf [bnc#625883]
* Mon Jun 28 2010 pgajdos@suse.cz
- updated to 1.4.3: fixed libpng overflow (CVE-2010-1205)
  and memory leak [bnc#617866]
* Fri Jun  4 2010 coolo@novell.com
- remove devel packages from baselibs.conf, not convinced of
  their usefulness
* Mon May  3 2010 dmueller@suse.de
- also obsolete libpng-devel-1.2.43 (previous factory version)
* Sat Apr 24 2010 coolo@novell.com
- buildrequire pkg-config to fix provides
* Thu Apr 15 2010 pgajdos@suse.cz
- support png_read_dither() for xfig and transfig
  * read-dither.patch
* Tue Apr  6 2010 ro@suse.de
- fix baselibs.conf
* Thu Mar 25 2010 pgajdos@suse.cz
- updated to 1.4.1 -- new branch
* Thu Feb 25 2010 pgajdos@suse.cz
- updated to 1.2.43 (fixes [bnc#585403]):
  * Removed "#define PNG_NO_ERROR_NUMBERS" that was inadvertently added
    to pngconf.h in version 1.2.41.
  * Removed leftover "-DPNG_CONFIGURE_LIBPNG" from scripts/makefile.darwin
    and contrib/pngminim/*/makefile
  * Relocated png_do_chop() to its original position in pngrtran.c; the
    change in version 1.2.41beta08 caused transparency to be handled wrong
    in some 16-bit datastreams (Yusaku Sugai).
  * Renamed libpng-pc.in back to libpng.pc.in and revised CMakeLists.txt
    (revising changes made in 1.2.41)
  * Swapped PNG_UNKNOWN_CHUNKS_SUPPORTED and PNG_HANDLE_AS_UNKNOWN_SUPPORTED
    in pngset.c to be consistent with other changes in version 1.2.38.
  * Avoid deprecated references to png_ptr-io_ptr and png_ptr->error_ptr
    in pngtest.c
* Mon Dec 14 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Mon Dec  7 2009 pgajdos@suse.cz
- updated to 1.2.41:
  contains numerous cleanups, some new compile-time warnings about
  direct struct access (define PNG_NO_PEDANTIC_WARNINGS to enable),
  a new xcode build project, and a minor performance improvement
  (avoid building 16-bit gamma tables when not needed)
* Tue Nov 24 2009 pgajdos@suse.cz
- updated to 1.2.40:
  Removed an extra png_debug() recently added to png_write_find_filter().
  Fixed incorrect #ifdef in pngset.c regarding unknown chunk support.
  Various bugfixes and improvements to CMakeLists.txt (Philip Lowman)
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Thu Aug 13 2009 pgajdos@suse.cz
- updated to 1.2.39:
  * Added a prototype for png_64bit_product() in png.c
  * Avoid a possible NULL dereference in debug build,
    in png_set_text_2()
  * Relocated new png_64_bit_product() prototype into png.h
  * Replaced *.tar.lzma with *.txz in distribution.
  * Reject attempt to write iCCP chunk with negative embedded
    profile length.
* Mon Jul 20 2009 pgajdos@suse.cz
- updated to 1.2.38:
  * Revised libpng*.txt and libpng.3 to mention calling png_set_IHDR()
    multiple times and to specify the sample order in the tRNS chunk,
    because the ISO PNG specification has a typo in the tRNS table.
  * Changed several PNG_UNKNOWN_CHUNK_SUPPORTED to
    PNG_HANDLE_AS_UNKNOWN_SUPPORTED, to make the png_set_keep mechanism
    available for ignoring known chunks even when not saving unknown chunks.
  * Adopted preference for consistent use of "#ifdef" and "#ifndef" versus
    "#if defined()" and "if !defined()" where possible.
  * Added PNG_NO_HANDLE_AS_UNKNOWN in the PNG_LEGACY_SUPPORTED block of
    pngconf.h, and moved the various unknown chunk macro definitions
    outside of the PNG_READ|WRITE_ANCILLARY_CHUNK_SUPPORTED blocks.
* Thu Jun  4 2009 pgajdos@suse.cz
- updated to 1.2.37:
  * fixed bug with new png_memset() of the big_row_buffer
* Tue May 12 2009 pgajdos@suse.cz
- updated to 1.2.36 (see CHANGES)
* Mon Feb 23 2009 pgajdos@suse.cz
- fixes possible double free [bnc#472745]
  (CVE-2009-0040)
* Mon Jan 19 2009 pgajdos@suse.cz
- updated to 1.2.34:
  * fixes CVE-2008-3964 (removed CVE-2008-3964.patch)
* Tue Jan 13 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Mon Sep 15 2008 pgajdos@suse.cz
- fixed CVE-2008-3964 [bnc#424739]
  * CVE-2008-3964.patch
* Thu Sep 11 2008 pgajdos@suse.cz
- updated to version 1.2.31:
  * coding bugfixes and enhancements
* Mon Sep  1 2008 aj@suse.de
- Do not package la files.
* Mon Jun 23 2008 pgajdos@suse.cz
- updated to 1.2.29:
  * fixes to the configure-related build-scripts
  * security fix that affects programs that attempt to do
    special handling of unknown PNG chunks (presumably very
    few such programs), along with a reversion to previous
    behavior for handling of images with out-of-range tRNS-chunk
    values [bnc#378634]
  * fix for unintentional gray-to-RGB conversion in
    png_set_expand_gray_1_2_4_to_8()
  * various other minor fixes
- removed makefile-am.patch, issue fixed upstream
* Sun May 11 2008 coolo@suse.de
- fix rename of xxbit packages
* Tue Apr 22 2008 pgajdos@suse.cz
- $(ECHO) substituted by echo in Makefile.in -- fixes package
  build in beta (makefile-am.patch)
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Thu Apr  3 2008 pgajdos@suse.cz
- updated to 1.2.26:
  * fixed minor coding errors that could lead to crashes in
    exceptional cases
* Thu Dec  6 2007 mrueckert@suse.de
- added provides/obsoletes for the old package
* Fri Nov 30 2007 nadvornik@suse.cz
- updated to 1.2.23:
  * more sanity checks, fixes [#332249]
- adjusted to Shared Library Policy:
  * renamed package libpng to libpng12-0
  * created compatibility package libpng3
* Wed Jul 11 2007 nadvornik@suse.cz
- updated to 1.2.18:
  * security fixes merged upstream
* Thu Mar 29 2007 aj@suse.de
- Add zlib-devel to BuildRequires.
* Thu Nov 23 2006 nadvornik@suse.cz
- fixed crash on malformed sPLT chunks CVE-2006-5793 [#219007]
* Mon Jul 17 2006 nadvornik@suse.cz
- make sure PNG_NO_ASSEMBLER_CODE is used consistently
* Thu Jun 29 2006 nadvornik@suse.cz
- updated to 1.2.12:
  * fixed possible buffer overflow [#189241]
* Wed Jun 21 2006 nadvornik@suse.cz
- updated to 1.2.10:
  * use autoconf
  * many bugfixes
- libpng12-config no longer gives -Wl,-rpath,/usr/lib [#168627]
- spec file cleanup
* Fri Feb 24 2006 nadvornik@suse.cz
- removed libpng-64bit.diff [#153106]
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 12 2006 nadvornik@suse.cz
- compile with -fstack-protector
* Mon Oct 10 2005 nadvornik@suse.cz
- fixed incorrect inline asm usage
* Thu May 19 2005 ro@suse.de
- fix libdir in pkgconfig file libpng.pc
* Thu Jan 20 2005 nadvornik@suse.cz
- updated to 1.2.8:
  * fixed crash of applications that strip the alpha channel
  * fixed invalid zlib header within the PNG datastream
* Mon Sep 27 2004 sf@suse.de
-  fixed problem with wrong assumption for long on 64bit archs
  which prevents khunphan from working (#45738)
* Wed Aug 25 2004 kukuk@suse.de
- Avoid /bin/sh PreRequires
* Mon Aug 16 2004 nadvornik@suse.cz
- updated to 1.2.6: included security fixes
* Mon Jul 19 2004 nadvornik@suse.cz
- fixed several buffer overflows [#43008]
* Wed Jun 16 2004 nadvornik@suse.cz
- added missing part of pngtran overflow patch [#42043]
* Fri Apr 23 2004 nadvornik@suse.cz
- fixed reading behind end of string [#39180]
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Fri Oct 10 2003 adrian@suse.de
- add %%run_ldconfig
* Mon Apr  7 2003 ro@suse.de
- fix tail calling syntax
* Mon Feb 10 2003 nadvornik@suse.cz
- link the shared library with -lz -lm -lc again
* Wed Jan 29 2003 kukuk@suse.de
- Fix libpng-devel requires (add zlib-devel) [Bug #23154]
* Fri Jan 24 2003 sbrabec@suse.cz
- Added missing pkgconfig files to %%files.
* Tue Jan  7 2003 nadvornik@suse.cz
- updated to 1.2.5
- fixed buffer overflow
* Wed Jul 31 2002 coolo@suse.de
- fix libz dependency, so the resulting libpng is self containing
* Fri Jul 26 2002 adrian@suse.de
- fix neededforbuild
* Wed Jul 24 2002 nadvornik@suse.cz
- updated to 1.2.4:
  - fixed buffer overflow in pngpread.c when IDAT is
    corrupted with extra data
* Fri Jul 12 2002 schwab@suse.de
- Fix makefile.
* Fri Jul  5 2002 kukuk@suse.de
- Use %%ix86 macro
* Tue Jul  2 2002 nadvornik@suse.cz
- updated to 1.2.3
- changed package version to match the version of source tarball
* Tue Mar  5 2002 nadvornik@suse.cz
- fixed permissions for man pages
* Tue Feb  5 2002 nadvornik@suse.cz
- added Provides: libpng:/usr/include/png.h to libpng-devel
* Thu Jan 31 2002 nadvornik@suse.cz
- back to 1.0.12, libpng 1.2.x will be packed in separate package
- created devel subpackage to allow parallel instalation of
  shared libraries
* Wed Jan  9 2002 nadvornik@suse.cz
- update to 1.2.1
- used macros %%{_lib} and %%{_libdir}
* Tue Dec  4 2001 nadvornik@suse.cz
- update to 1.2.0
  - shared library version changed to 3.1.2.0
  - new API for dynamically enabling and disabling certain optimizations
- added Provides: libpng-devel for compatibility [bug #11978]
* Tue Jul 17 2001 nadvornik@suse.cz
- update to 1.0.12
* Tue Apr  3 2001 nadvornik@suse.cz
- update to 1.0.10
- used pnggccrd.c - MMX support on intel
* Tue Feb 13 2001 nadvornik@suse.cz
- update to 1.0.9
* Fri Jan 19 2001 bk@suse.de
- call pngtest program to have some tests that libpng works.
- don't remove -O3 when adding RPM_OPT_FLAGS(still do -O3 optimisations)
* Thu Jan  4 2001 nadvornik@suse.cz
- changed rpm version to 2.1.0.8 (bug #5062)
- changed shared library name to libpng.so.2.1.0.8
* Wed Aug 23 2000 nadvornik@suse.cz
- update to 1.0.8
* Tue Jul 11 2000 adrian@suse.de
- seg fault fix in pngrutil.c
* Mon May 22 2000 nadvornik@suse.cz
- changed group
- changed URL
* Sat Apr 29 2000 kukuk@suse.de
- Make sure libpng.so.2 is linked against libz to avoid problems
  with missing dependencies.
* Mon Apr 10 2000 nadvornik@suse.cz
- added URL
* Tue Apr  4 2000 nadvornik@suse.cz
- update to 1.0.6
- added BuildRoot
* Tue Jan 25 2000 ro@suse.de
- update to 1.0.5
- manpages to /usr/share using macro
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Tue Jun 29 1999 ro@suse.de
- moved from /usr/X11R6 to /usr
* Mon Jun 28 1999 ro@suse.de
- update to 1.0.3
* Wed Feb 17 1999 ro@suse.de
- added .so.2 link
* Fri Jan 22 1999 ro@suse.de
- bump version to 2.1.0 (the version of the installed library)
* Fri Mar 20 1998 ro@suse.de
- extracted package from libgr tree
  update to version 1.0.1
